.. _tutorial2:

====================================
Using SPM for analysis: Hierarchical
====================================

Copy over the spm_tutorial2.py script from the examples folder or cut
and paste the document included below into a file. Then run the
tutorial from inside the nipype tutorial directory.

::
        python spm_tutorial2.py


.. include:: ../examples/spm_tutorial2.rst

.. include:: ../links_names.txt
